@@ -1,5 +1,5 @@
 package Elasticsearch::Client::Direct::Cat;
-$Elasticsearch::Client::Direct::Cat::VERSION = '1.01';
+$Elasticsearch::Client::Direct::Cat::VERSION = '1.02';
 use Moo;
 with 'Elasticsearch::Role::API';
 with 'Elasticsearch::Role::Client::Direct';
@@ -28,7 +28,7 @@ Elasticsearch::Client::Direct::Cat - A client for running cat debugging requests
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 DESCRIPTION
 
@@ -262,11 +262,26 @@ Query string parameters:
 See the L<cat shards docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cat-shards.html>
 for more information.
 
-    "cat.shards" => {
-        doc  => "cat-shards",
-        path => "/_cat/shards/{index}",
-        qs   => [ "local", "master_timeout", "h", "help", "v" ],
-    },
+=head2 C<thread_pool()>
+
+    say $e->cat->thread_pool(
+        index => 'index' | \@indices    # optional
+    );
+
+Shows cluster wide thread pool statistics per node. By default the C<active>,
+C<queue> and C<rejected> statistics are returned for the C<bulk>, C<index> and
+C<search> thread pools.
+
+Query string parameters:
+    C<full_id>,
+    C<h>,
+    C<help>,
+    C<local>,
+    C<master_timeout>,
+    C<v>
+
+See the L<cat thread_pool docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cat-thread-pool.html>
+for more information.
 
 =head1 AUTHOR
 
